/*
 * Email Verification Page
 * Handles sending/resending verification email to user
 */

import React from "react";
import { Pane, Heading, Button, Paragraph, Link } from "evergreen-ui";
import { emailSendStart } from "./actions";
import { connect } from "react-redux";
import PropTypes from "prop-types";
import { createStructuredSelector } from "reselect";
import { makeSignupCreateEmail } from "../SignupPage/selectors";

interface IEmailSendPageProps{
  onResend: Function;
  email: string;
}

export function EmailSendPage ({
  onResend,
  email
}:IEmailSendPageProps) {

  /**
   * Function handles the email resend
   */
  const handleResend = () => {
    onResend(email);
  };

  return (
    <Pane marginY={100} data-test="emailSendPageComponent">
      <Pane
        justifyContent="center"
        width="35%"
        elevation={1}
        margin="auto"
        padding={5}
      >
        <Heading
          size={700}
          textAlign="center"
          marginBottom={20}
          paddingTop={20}
        >
          Email Sent
        </Heading>
        <Paragraph size={300} width="60%" marginLeft="20%" marginBottom={5}>
          We have sent a mail to verify your email address.
        </Paragraph>
        <Paragraph size={300} width="60%" marginLeft="20%">
          If you don't receive, please click here to:
          <br />
          <Link>
            <Button
              width="20%"
              marginLeft="40%"
              justifyContent="center"
              appearance="primary"
              intent="none"
              marginTop={10}
              marginBottom={10}
              onClick={handleResend}
            >
              Resend
            </Button>
          </Link>
        </Paragraph>
        <Paragraph size={300} width="60%" marginLeft="20%" marginBottom={15}>
          Once you verify, <Link href="/login">Login</Link> here
        </Paragraph>
        <Paragraph size={300} width="60%" marginLeft="20%" marginBottom={20}>
          If you don't find it in your inbox, check spam folder.
        </Paragraph>
      </Pane>
    </Pane>
  );
}

EmailSendPage.propTypes = {
  onResend: PropTypes.func,
  email: PropTypes.string
};

const mapStateToProps = createStructuredSelector({
  email: makeSignupCreateEmail
});

const mapDispatchToProps = (dispatch: Function) => {
  return {
    onResend: (email: string) => dispatch(emailSendStart(email))
  };
};

export default connect(
  mapStateToProps,
  mapDispatchToProps
)(EmailSendPage);
